@@ -4,13 +4,13 @@
  * terms of the GNU General Public License, see the file COPYING.
  */
 
-#define VERSION "1.1"
+#define VERSION "1.1.1"
 #define PATCHLEVEL 0
-#define REVDATE "27 May 93"
+#define REVDATE "1 Jun 93"
 
 /* This version does not support compression into old compress format: */
 #ifdef LZW
 #  undef LZW
 #endif
 
-/* $Id: revision.h,v 0.18 1993/03/18 18:14:56 jloup Exp $ */
+/* $Id: revision.h,v 0.20 1993/06/01 14:03:17 jloup Exp $ */
